aboutsummaryrefslogtreecommitdiff
path: root/id/server/idserverlib/src/main/java/at/gv/egovernment/moa/id/auth/stork
diff options
context:
space:
mode:
authorFlorian Reimair <florian.reimair@iaik.tugraz.at>2014-01-31 08:55:04 +0100
committerFlorian Reimair <florian.reimair@iaik.tugraz.at>2014-01-31 17:17:31 +0100
commit5ee3da37829fa14d70ad827e19364be4800fab37 (patch)
treee134685762f1a1b88aaaae99aae2801de7ddf05f /id/server/idserverlib/src/main/java/at/gv/egovernment/moa/id/auth/stork
parente1e410da00a399a8b059645a14a7848b39d3525c (diff)
downloadmoa-id-spss-5ee3da37829fa14d70ad827e19364be4800fab37.tar.gz
moa-id-spss-5ee3da37829fa14d70ad827e19364be4800fab37.tar.bz2
moa-id-spss-5ee3da37829fa14d70ad827e19364be4800fab37.zip
fixed target type for MIS info
Diffstat (limited to 'id/server/idserverlib/src/main/java/at/gv/egovernment/moa/id/auth/stork')
-rw-r--r--id/server/idserverlib/src/main/java/at/gv/egovernment/moa/id/auth/stork/STORKResponseProcessor.java21
1 files changed, 11 insertions, 10 deletions
diff --git a/id/server/idserverlib/src/main/java/at/gv/egovernment/moa/id/auth/stork/STORKResponseProcessor.java b/id/server/idserverlib/src/main/java/at/gv/egovernment/moa/id/auth/stork/STORKResponseProcessor.java
index 6d88a1684..20ceb2128 100644
--- a/id/server/idserverlib/src/main/java/at/gv/egovernment/moa/id/auth/stork/STORKResponseProcessor.java
+++ b/id/server/idserverlib/src/main/java/at/gv/egovernment/moa/id/auth/stork/STORKResponseProcessor.java
@@ -144,16 +144,17 @@ public class STORKResponseProcessor {
}
/**
* Handels connection to SZR-GW and returns Identity Link on success
* @param oaFriendlyName
* @param target
* @param filters
* @param filter
* @param iPersonalAttributeList Received attribute List in assertion
* @return Identity Link
- * @throws STORKException
+ * @throws STORKException the sTORK exception
*/
- public static IdentityLink connectToSZRGateway(IPersonalAttributeList attributeList, String oaFriendlyName, String target, String filters) throws STORKException {
+ public static IdentityLink connectToSZRGateway(IPersonalAttributeList attributeList, String oaFriendlyName, String targetType, String targetValue, String filters) throws STORKException {
Logger.trace("Calling SZR Gateway with the following attributes:");
CreateIdentityLinkResponse identityLinkResponse = null;
@@ -177,7 +178,7 @@ public class STORKResponseProcessor {
String organizationAddress = getAttributeValue("canonicalRegisteredAddress", attributeList);
String organizationType = getAttributeValue("translateableType", attributeList);
- identityLinkResponse = AuthenticationServer.getInstance().getIdentityLink(citizenSignature, representative, represented, mandate, organizationAddress, organizationType, target, oaFriendlyName, filters);
+ identityLinkResponse = AuthenticationServer.getInstance().getIdentityLink(citizenSignature, representative, represented, mandate, organizationAddress, organizationType, targetType, targetValue, oaFriendlyName, filters);
} else {
// if we get here, we have a natural person representing another natural person
String eIdentifier = getAttributeValue("eIdentifier", attributeList);
@@ -192,7 +193,7 @@ public class STORKResponseProcessor {
identityLinkResponse = AuthenticationServer.getInstance().getIdentityLink(eIdentifier,
givenName, lastName, dateOfBirth, gender, citizenSignature, representative,
- represented, mandate, target, oaFriendlyName, filters);
+ represented, mandate, targetType, targetValue, oaFriendlyName, filters);
}
} else {
// we do not have a representation case
@@ -144,16 +144,17 @@ public class STORKResponseProcessor {
}
/**
- * Handels connection to SZR-GW and returns Identity Link on success
- * @param oaFriendlyName
- * @param target
- * @param filters
- * @param filter
- * @param iPersonalAttributeList Received attribute List in assertion
+ * Handels connection to SZR-GW and returns Identity Link on success.
+ *
+ * @param attributeList the attribute list
+ * @param oaFriendlyName the oa friendly name
+ * @param targetType the target type
+ * @param targetValue the target value
+ * @param filters the filters
* @return Identity Link